from flask import Blueprint, request, jsonify
from src.models.user import db, User

user_bp = Blueprint('user', __name__)

@user_bp.route('/api/users/register', methods=['POST'])
def register_user():
    data = request.get_json()
    
    # Validate required fields
    if not data or not data.get('email'):
        return jsonify({'error': 'Email is required'}), 400
    
    # Check if user already exists
    existing_user = User.query.filter_by(email=data.get('email')).first()
    if existing_user:
        return jsonify({'error': 'Email already registered'}), 409
    
    # Create new user
    new_user = User(
        email=data.get('email'),
        name=data.get('name', ''),
        newsletter_subscription=data.get('newsletter_subscription', True)
    )
    
    try:
        db.session.add(new_user)
        db.session.commit()
        return jsonify({'message': 'User registered successfully', 'user': new_user.to_dict()}), 201
    except Exception as e:
        db.session.rollback()
        return jsonify({'error': f'Registration failed: {str(e)}'}), 500

@user_bp.route('/api/users/newsletter', methods=['POST'])
def newsletter_signup():
    data = request.get_json()
    
    # Validate required fields
    if not data or not data.get('email'):
        return jsonify({'error': 'Email is required'}), 400
    
    # Check if user already exists
    existing_user = User.query.filter_by(email=data.get('email')).first()
    
    if existing_user:
        # Update existing user's newsletter preference if they already exist
        existing_user.newsletter_subscription = True
        try:
            db.session.commit()
            return jsonify({'message': 'Newsletter subscription updated', 'user': existing_user.to_dict()}), 200
        except Exception as e:
            db.session.rollback()
            return jsonify({'error': f'Subscription update failed: {str(e)}'}), 500
    else:
        # Create new user with newsletter subscription
        new_user = User(
            email=data.get('email'),
            newsletter_subscription=True
        )
        
        try:
            db.session.add(new_user)
            db.session.commit()
            return jsonify({'message': 'Newsletter subscription successful', 'user': new_user.to_dict()}), 201
        except Exception as e:
            db.session.rollback()
            return jsonify({'error': f'Subscription failed: {str(e)}'}), 500
